FindMyFriends is supported
natively (And FindMyFriends support grouping based on other algorithms),
while more general use is supported by supplying a pangenome matrix along
with functional annotation of each row. A last option is to provide the file
path to a csv file containing the pangenome matrix along with the functional
annotation.
panviz(object, ...)
"panviz"(object, name = "name", go = "go", ec = "ec", ignore, location, consolidate = TRUE, showcase = FALSE, ...)
"panviz"(object, location, useDescription = TRUE, consolidate = TRUE, showcase = FALSE, ...)
"panviz"(object, name, go, ec, location, consolidate = TRUE, showcase = FALSE, ...)
"panviz"(object, ...)showcase=TRUE the resulting PanViz.html file will be opened in the
default browser.
character: Method for file paths pgVirtual: Method for pgVirtual subclasses from FindMyFriends matrix: Method for pangenome matrix as numeric/integer matrix data.frame: Method for pangenome matrix as data.frame (will be coerced
to matrix)
dist (default: 'canberra') for setting the
method used in the dist calls, clust (default:
'ward.D2') for setting the method used in the hclust
calls, center (default: TRUE) to control whether variables should be
centered prior to doing PCA and scale (default: TRUE) to control
whether scaling should be performed prior to PCA.When using panviz with a csv file the name, go and
ec parameters should point to the columns in the csv file containing
the respective information, either by name or index. If E.C. annotation is
not given in the csv file it can be set to NA. For column with multiple
possible values (go and ec) any delimiter can be used but ',', '.', and
numbers (don't know why you would use numbers as delimiter anyway).
For panviz with a matrix or data.frame the name, go and
ec parameters should contain the actual annotation as character
vectors or lists of strings. For character vectors the same delimiting
restrictions exists as for csv files described above. ec and
name can be omitted. If name is missing the rownames of the
matrix or data.frame will be used instead - if these are not present an error
will be thrown. name, go and ec must match the number of
rows in the pangenome matrix if given.
PanVizGenerator for a shiny interface to converting
csv files.
if(interactive()) {
exampleFile <- system.file('extdata', 'exampleData.csv')
panviz(exampleFile, location = tempdir(), showcase = TRUE)
}
Run the code above in your browser using DataLab